@@ -1,17 +1,26 @@
-/* exported ChatView */
+export { ChatView };
 
-const {
-    Gdk, Gio, GLib, GObject, Gtk, Pango, PangoCairo, Polari,
-    TelepathyGLib: Tp, TelepathyLogger: Tpl,
-} = imports.gi;
+import Gdk from 'gi://Gdk';
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
+import Pango from 'gi://Pango';
+import PangoCairo from 'gi://PangoCairo';
+import Polari from 'gi://Polari';
+import Tp from 'gi://TelepathyGLib';
+import Tpl from 'gi://TelepathyLogger';
 
-const { DropTargetIface } = imports.pasteManager;
-const { UserPopover } = imports.userList;
-const { UserStatusMonitor } = imports.userTracker;
-const { URLPreview } = imports.urlPreview;
-const Utils = imports.utils;
+import { DropTargetIface } from './pasteManager.js';
+import { UserPopover } from './userList.js';
+import { UserStatusMonitor } from './userTracker.js';
+import { URLPreview } from './urlPreview.js';
+import * as Utils from './utils.js';
 
-var MAX_NICK_CHARS = 8;
+Gio._promisify(Tpl.LogWalker.prototype,
+    'get_events_async', 'get_events_finish');
+
+export const MAX_NICK_CHARS = 8;
 const IGNORE_STATUS_TIME = 5;
 
 const SCROLL_TIMEOUT = 100; // ms
@@ -273,7 +282,7 @@ const HoverFilterTag = GObject.registerClass({
     }
 });
 
-var ChatView = GObject.registerClass({
+const ChatView = GObject.registerClass({
     Implements: [DropTargetIface],
     Properties: {
         'can-drop': GObject.ParamSpec.override('can-drop', DropTargetIface),
@@ -314,6 +323,8 @@ var ChatView = GObject.registerClass({
         this.vadjustment.connect('value-changed',
             this._onValueChanged.bind(this));
         this.vadjustment.connect('changed', this._updateScroll.bind(this));
+        this.vadjustment.connect('notify::upper',
+            this._onUpperChanged.bind(this));
 
         this._view.connect('key-press-event', this._onKeyPress.bind(this));
         this._view.connect('motion-notify-event',
@@ -359,10 +370,10 @@ var ChatView = GObject.registerClass({
             Tpl.EventTypeMask.TEXT, null);
 
         this._fetchingBacklog = true;
-        this._logWalker.get_events_async(NUM_INITIAL_LOG_EVENTS,
-            this._onLogEventsReady.bind(this));
+        this._getLogEvents(NUM_INITIAL_LOG_EVENTS);
 
         this._autoscroll = true;
+        this._originalUpper = this.vadjustment.get_upper();
 
         this._app = Gio.Application.get_default();
         DropTargetIface.addTargets(this, this._view);
@@ -549,11 +560,12 @@ var ChatView = GObject.registerClass({
         this._logWalker = null;
     }
 
-    _onLogEventsReady(lw, res) {
+    async _getLogEvents(num) {
+        const [events] = await this._logWalker.get_events_async(num);
+
         this._hideLoadingIndicator();
         this._fetchingBacklog = false;
 
-        let [, events] = lw.get_events_finish(res);
         let messages = events.map(e => this._createMessage(e));
         this._pendingLogs = messages.concat(this._pendingLogs);
         this._insertPendingLogs();
@@ -633,6 +645,10 @@ var ChatView = GObject.registerClass({
         let iter = this._view.buffer.get_start_iter();
 
         for (let i = 0; i < pending.length; i++) {
+            // Workaround https://gitlab.gnome.org/GNOME/gtk/merge_requests/395
+            this.set_kinetic_scrolling(false);
+            this._insertingBacklog = true;
+
             this._insertMessage(iter, pending[i], state);
 
             if (i === indicatorIndex)
@@ -744,8 +760,7 @@ var ChatView = GObject.registerClass({
         this._fetchingBacklog = true;
         this._showLoadingIndicator();
         this._backlogTimeoutId = GLib.timeout_add(GLib.PRIORITY_DEFAULT, 500, () => {
-            this._logWalker.get_events_async(NUM_LOG_EVENTS,
-                this._onLogEventsReady.bind(this));
+            this._getLogEvents(NUM_LOG_EVENTS);
             this._backlogTimeoutId = 0;
             return GLib.SOURCE_REMOVE;
         });
@@ -763,6 +778,20 @@ var ChatView = GObject.registerClass({
         });
     }
 
+    _onUpperChanged() {
+        const newUpper = this.vadjustment.get_upper();
+        const diff = newUpper - this._originalUpper;
+
+        if (diff !== 0.0) {
+            this._originalUpper = newUpper;
+            if (this._insertingBacklog) {
+                this.vadjustment.set_value(this.vadjustment.get_value() + diff);
+                this.set_kinetic_scrolling(true);
+                this._insertingBacklog = false;
+            }
+        }
+    }
+
     _pendingMessageRemoved(channel, message) {
         let [id, valid] = message.get_pending_message_id();
         if (!valid || !this._pending.has(id))
