@@ -1,10 +1,25 @@
-/* exported ConnectionProperties ConnectionDetails ConnectionsList */
+export {
+    ConnectionProperties,
+    ConnectionDetails,
+    ConnectionsList
+};
 
-const { GLib, GObject, Gtk, TelepathyGLib: Tp } = imports.gi;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
+import Tp from 'gi://TelepathyGLib';
 
-const { AccountsMonitor } = imports.accountsMonitor;
-const { NetworksManager } = imports.networksManager;
-const Utils = imports.utils;
+import { AccountsMonitor } from './accountsMonitor.js';
+import { NetworksManager } from './networksManager.js';
+import * as Utils from './utils.js';
+
+Gio._promisify(Tp.Account.prototype,
+    'set_display_name_async', 'set_display_name_finish');
+Gio._promisify(Tp.Account.prototype,
+    'update_parameters_vardict_async', 'update_parameters_vardict_finish');
+Gio._promisify(Tp.AccountRequest.prototype,
+    'create_account_async', 'create_account_finish');
 
 const DEFAULT_PORT = 6667;
 const DEFAULT_SSL_PORT = 6697;
@@ -33,7 +48,13 @@ class ConnectionRow extends Gtk.ListBoxRow {
             this, 'activatable',
             GObject.BindingFlags.SYNC_CREATE);
 
-        let box = new Gtk.Box({ spacing: 12, margin: 12 });
+        let box = new Gtk.Box({
+            spacing: 12,
+            margin_start: 12,
+            margin_end: 12,
+            margin_top: 12,
+            margin_bottom: 12,
+        });
         this.add(box);
 
         box.add(new Gtk.Label({ label: name, halign: Gtk.Align.START }));
@@ -59,7 +80,7 @@ class ConnectionRow extends Gtk.ListBoxRow {
     }
 });
 
-var ConnectionsList = GObject.registerClass({
+const ConnectionsList = GObject.registerClass({
     Properties: {
         'favorites-only': GObject.ParamSpec.boolean(
             'favorites-only', 'favorites-only', 'favorites-only',
@@ -196,7 +217,7 @@ var ConnectionsList = GObject.registerClass({
         });
     }
 
-    _onRowActivated(list, row) {
+    async _onRowActivated(list, row) {
         let name = this._networksManager.getNetworkName(row.id);
         let req = new Tp.AccountRequest({
             account_manager: Tp.AccountManager.dup(),
@@ -212,17 +233,14 @@ var ConnectionsList = GObject.registerClass({
         for (let prop in details)
             req.set_parameter(prop, details[prop]);
 
-        req.create_account_async((r, res) => {
-            let account = req.create_account_finish(res);
-            if (!account) // TODO: Handle errors
-                return;
-
-            Utils.clearAccountPassword(account);
-            Utils.clearIdentifyPassword(account);
-
-            this.emit('account-created', account);
-        });
         this.emit('account-selected');
+
+        const account = await req.create_account_async();
+
+        Utils.clearAccountPassword(account);
+        Utils.clearIdentifyPassword(account);
+
+        this.emit('account-created', account);
     }
 
     _setAccountRowSensitive(account, sensitive) {
@@ -249,7 +267,7 @@ var ConnectionsList = GObject.registerClass({
     }
 });
 
-var ConnectionDetails = GObject.registerClass({
+const ConnectionDetails = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/connection-details.ui',
     InternalChildren: [
         'nameEntry',
@@ -432,7 +450,7 @@ var ConnectionDetails = GObject.registerClass({
             this._createAccount();
     }
 
-    _createAccount() {
+    async _createAccount() {
         let params = this._getParams();
         let accountManager = Tp.AccountManager.dup();
         let req = new Tp.AccountRequest({
@@ -448,32 +466,25 @@ var ConnectionDetails = GObject.registerClass({
         for (let prop in details)
             req.set_parameter(prop, details[prop]);
 
-        req.create_account_async((r, res) => {
-            let account = req.create_account_finish(res);
-            if (!account) // TODO: Handle errors
-                return;
+        const account = await req.create_account_async();
 
-            Utils.clearAccountPassword(account);
-            Utils.clearIdentifyPassword(account);
+        Utils.clearAccountPassword(account);
+        Utils.clearIdentifyPassword(account);
 
-            this.emit('account-created', account);
-        });
+        this.emit('account-created', account);
     }
 
-    _updateAccount() {
+    async _updateAccount() {
         let params = this._getParams();
         let account = this._account;
         let oldDetails = account.dup_parameters_vardict().deep_unpack();
         let [details, removed] = this._detailsFromParams(params, oldDetails);
         let vardict = GLib.Variant.new('a{sv}', details);
 
-        account.update_parameters_vardict_async(vardict, removed, (a, res) => {
-            a.update_parameters_vardict_finish(res); // TODO: Check for errors
-        });
-
-        account.set_display_name_async(params.name, (a, res) => {
-            a.set_display_name_finish(res); // TODO: Check for errors
-        });
+        await Promise.all([
+            account.update_parameters_vardict_async(vardict, removed),
+            account.set_display_name_async(params.name),
+        ]);
     }
 
     _detailsFromParams(params, oldDetails) {
@@ -497,7 +508,7 @@ var ConnectionDetails = GObject.registerClass({
 });
 
 
-var ConnectionProperties = GObject.registerClass({
+const ConnectionProperties = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/connection-properties.ui',
     InternalChildren: [
         'details',
