@@ -1,19 +1,30 @@
-/* exported ChatEntry EntryArea NickPopover */
+export {
+    ChatEntry,
+    EntryArea,
+    NickPopover
+};
 
-const {
-    Gdk, GdkPixbuf, Gio, GLib, GObject, Gspell, Gtk, TelepathyGLib: Tp,
-} = imports.gi;
+import Gdk from 'gi://Gdk';
+import GdkPixbuf from 'gi://GdkPixbuf';
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gspell from 'gi://Gspell';
+import Gtk from 'gi://Gtk';
+import Tp from 'gi://TelepathyGLib';
 
-const ChatView = imports.chatView;
-const { DropTargetIface } = imports.pasteManager;
-const { IrcParser } = imports.ircParser;
-const { TabCompletion } = imports.tabCompletion;
+import { MAX_NICK_CHARS } from './chatView.js';
+import { DropTargetIface } from './pasteManager.js';
+import { IrcParser } from './ircParser.js';
+import { TabCompletion } from './tabCompletion.js';
 
 const MAX_NICK_UPDATE_TIME = 5; /* s */
 const MAX_LINES = 5;
 
+Gio._promisify(Gio._LocalFilePrototype,
+    'query_info_async', 'query_info_finish');
 
-var ChatEntry = GObject.registerClass({
+const ChatEntry = GObject.registerClass({
     Implements: [DropTargetIface],
     Properties: {
         'can-drop': GObject.ParamSpec.override('can-drop', DropTargetIface),
@@ -104,7 +115,7 @@ var ChatEntry = GObject.registerClass({
     }
 });
 
-var NickPopover = GObject.registerClass({
+const NickPopover = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/nick-popover.ui',
     InternalChildren: [
         'nickEntry',
@@ -152,7 +163,7 @@ var NickPopover = GObject.registerClass({
     }
 });
 
-var EntryArea = GObject.registerClass({
+const EntryArea = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/entry-area.ui',
     InternalChildren: [
         'chatEntry',
@@ -183,7 +194,7 @@ var EntryArea = GObject.registerClass({
         delete params.room;
 
         this._ircParser = new IrcParser(this._room);
-        this._maxNickChars = ChatView.MAX_NICK_CHARS;
+        this._maxNickChars = MAX_NICK_CHARS;
         this._nickChangedId = 0;
 
         super._init(params);
@@ -383,18 +394,13 @@ var EntryArea = GObject.registerClass({
         this._setPasteContent(pixbuf);
     }
 
-    pasteFile(file) {
-        file.query_info_async(
-            Gio.FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
-            Gio.FileQueryInfoFlags.NONE,
-            GLib.PRIORITY_DEFAULT, null,
-            this._onFileInfoReady.bind(this));
-    }
-
-    _onFileInfoReady(file, res) {
+    async pasteFile(file) {
         let fileInfo = null;
         try {
-            fileInfo = file.query_info_finish(res);
+            fileInfo = await file.query_info_async(
+                Gio.FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+                Gio.FileQueryInfoFlags.NONE,
+                GLib.PRIORITY_DEFAULT, null);
         } catch (e) {
             return;
         }
@@ -407,7 +413,7 @@ var EntryArea = GObject.registerClass({
         this._setPasteContent(file);
     }
 
-    _onPasteClicked() {
+    async _onPasteClicked() {
         let title;
         let nick = this._room.channel.connection.self_contact.alias;
         if (this._room.type === Tp.HandleType.ROOM)
@@ -415,24 +421,23 @@ var EntryArea = GObject.registerClass({
             title = _('%s in #%s').format(nick, this._room.display_name);
         else
             title = _('Paste from %s').format(nick);
+        this._confirmLabel.hide();
 
         this._confirmLabel.hide();
         this._uploadSpinner.start();
 
         let app = Gio.Application.get_default();
         try {
-            app.pasteManager.pasteContent(this._pasteContent, title, url => {
-                // TODO: handle errors
-                this._uploadSpinner.stop();
-                this._setPasteContent(null);
-                if (url)
-                    this._chatEntry.emit('insert-at-cursor', url);
-            });
+            const url =
+                await app.pasteManager.pasteContent(this._pasteContent, title);
+            this._setPasteContent(null);
+            this._chatEntry.emit('insert-at-cursor', url);
         } catch (e) {
             let type = typeof this._pasteContent;
             if (type === 'object')
                 type = this._pasteContent.toString();
             debug(`Failed to paste content of type ${type}`);
+        } finally {
             this._uploadSpinner.stop();
         }
     }
