@@ -1,8 +1,14 @@
-/* exported InitialSetupWindow */
+export { InitialSetupWindow };
 
-const { Gio, GLib, GObject, Gtk } = imports.gi;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
+import Tp from 'gi://TelepathyGLib';
 
-const Utils = imports.utils;
+import * as Utils from './utils.js';
+
+Gio._promisify(Tp.Account.prototype, 'remove_async', 'remove_finish');
 
 const SetupPage = {
     CONNECTION: 0,
@@ -10,7 +16,7 @@ const SetupPage = {
     OFFLINE: 2,
 };
 
-var InitialSetupWindow = GObject.registerClass({
+const InitialSetupWindow = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/initial-setup-window.ui',
     InternalChildren: [
         'contentStack',
@@ -86,21 +92,19 @@ var InitialSetupWindow = GObject.registerClass({
 
         let context = this._nextButton.get_style_context();
         if (isLastPage)
-            context.add_class(Gtk.STYLE_CLASS_SUGGESTED_ACTION);
+            context.add_class('suggested-action');
         else
-            context.remove_class(Gtk.STYLE_CLASS_SUGGESTED_ACTION);
+            context.remove_class('suggested-action');
 
         this._nextButton.grab_default();
         this._updateNextSensitivity();
     }
 
-    _unsetAccount() {
+    async _unsetAccount() {
         if (!this._currentAccount)
             return;
 
-        this._currentAccount.remove_async((a, res) => {
-            a.remove_finish(res);
-        });
+        await this._currentAccount.remove_async();
         this._currentAccount = null;
     }
 
