@@ -1,17 +1,25 @@
-/* exported IrcParser */
+export { IrcParser };
+
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import Tp from 'gi://TelepathyGLib';
 
-const { Gio, GLib, TelepathyGLib: Tp } = imports.gi;
 const Signals = imports.signals;
 
-const AppNotifications = imports.appNotifications;
-const { RoomManager } = imports.roomManager;
-const Utils = imports.utils;
+import * as AppNotifications from './appNotifications.js';
+import { RoomManager } from './roomManager.js';
+import * as Utils from './utils.js';
+
+Gio._promisify(Tp.Account.prototype,
+    'request_presence_async', 'request_presence_finish');
 Gio._promisify(Tp.Connection.prototype,
     'dup_contact_by_id_async', 'dup_contact_by_id_finish');
 Gio._promisify(Tp.Contact.prototype,
     'request_contact_info_async', 'request_contact_info_finish');
 
-var knownCommands = {
+const N_ = s => s;
+
+export const knownCommands = {
     /* commands that would be nice to support: */
     /*
     AWAY: N_("/AWAY [<message>] — sets or unsets away message"),
@@ -40,7 +48,9 @@ var knownCommands = {
 const UNKNOWN_COMMAND_MESSAGE =
     N_('Unknown command — try /HELP for a list of available commands');
 
-var IrcParser = class {
+const ROOM_PREFIXES = ['#', '&', '+', '!'];
+
+const IrcParser = class IrcParser {
     constructor(room) {
         this._app = Gio.Application.get_default();
         this._roomManager = RoomManager.getDefault();
@@ -100,17 +110,14 @@ var IrcParser = class {
                 retval = false;
                 break;
             }
-            this._room.channel.connection.dup_contact_by_id_async(nick, [],
-                (c, res) => {
-                    let contact;
-                    try {
-                        contact = c.dup_contact_by_id_finish(res);
-                    } catch (e) {
-                        logError(e, `Failed to get contact for ${nick}`);
-                        return;
-                    }
-                    this._room.add_member(contact);
-                });
+            try {
+                let connection = this._room.channel.connection;
+                let contact = await connection.dup_contact_by_id_async(nick);
+                this._room.add_member(contact);
+            } catch (e) {
+                logError(e, `Failed to get contact for ${nick}`);
+                retval = false;
+            }
             break;
         }
         case 'J':
@@ -123,7 +130,8 @@ var IrcParser = class {
             }
             if (argv.length)
                 log(`Excess arguments to JOIN command: ${argv}`);
-
+            if (!ROOM_PREFIXES.some(prefix => room.startsWith(prefix)))
+                room = `#${room}`;
             let { account } = this._room;
             let app = Gio.Application.get_default();
             let action = app.lookup_action('join-room');
@@ -141,17 +149,14 @@ var IrcParser = class {
                 retval = false;
                 break;
             }
-            this._room.channel.connection.dup_contact_by_id_async(nick, [],
-                (c, res) => {
-                    let contact;
-                    try {
-                        contact = c.dup_contact_by_id_finish(res);
-                    } catch (e) {
-                        logError(e, `Failed to get contact for ${nick}`);
-                        return;
-                    }
-                    this._room.remove_member(contact);
-                });
+            try {
+                let connection = this._room.channel.connection;
+                let contact = await connection.dup_contact_by_id_async(nick);
+                this._room.remove_member(contact);
+            } catch (e) {
+                logError(e, `Failed to get contact for ${nick}`);
+                retval = false;
+            }
             break;
         }
         case 'ME': {
@@ -247,14 +252,12 @@ var IrcParser = class {
         case 'QUIT': {
             let presence = Tp.ConnectionPresenceType.OFFLINE;
             let message = stripCommand(text);
-            this._room.account.request_presence_async(presence, 'offline', message,
-                (a, res) => {
-                    try {
-                        a.request_presence_finish(res);
-                    } catch (e) {
-                        logError(e, 'Failed to disconnect');
-                    }
-                });
+            try {
+                await this._room.account.request_presence_async(presence, 'offline', message);
+            } catch (e) {
+                logError(e, 'Failed to disconnect');
+                retval = false;
+            }
             break;
         }
         case 'SAY': {
@@ -318,15 +321,13 @@ var IrcParser = class {
         this._sendMessage(message);
     }
 
-    _sendMessage(message) {
-        this._room.channel.send_message_async(message, 0, (c, res) => {
-            try {
-                c.send_message_finish(res);
-            } catch (e) {
-                // TODO: propagate to user
-                logError(e, 'Failed to send message');
-            }
-        });
+    async _sendMessage(message) {
+        try {
+            await this._room.channel.send_message_async(message, 0);
+        } catch (e) {
+            // TODO: propagate to user
+            logError(e, 'Failed to send message');
+        }
     }
 };
 Signals.addSignalMethods(IrcParser.prototype);
