@@ -1,10 +1,12 @@
-/* exported TabCompletion */
+export { TabCompletion };
 
-const { Gdk, Gtk, Pango } = imports.gi;
+import Gdk from 'gi://Gdk';
+import Gtk from 'gi://Gtk';
+import Pango from 'gi://Pango';
 
-const IrcParser = imports.ircParser;
+import * as IrcParser from './ircParser.js';
 
-var TabCompletion = class {
+const TabCompletion = class {
     constructor(entry) {
         this._entry = entry;
         this._canComplete = false;
