@@ -1,15 +1,24 @@
-/* exported UserList UserListPopover UserDetails UserPopover */
+export {
+    UserList,
+    UserListPopover,
+    UserDetails,
+    UserPopover
+};
 
-const {
-    Gio, GLib, GObject, Gtk, Pango, Polari, TelepathyGLib: Tp,
-} = imports.gi;
+import Gio from 'gi://Gio';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
+import Pango from 'gi://Pango';
+import Polari from 'gi://Polari';
+import Tp from 'gi://TelepathyGLib';
 
-const Utils = imports.utils;
+import * as Utils from './utils.js';
 
 const FILTER_ENTRY_THRESHOLD = 8;
 const MAX_USERS_WIDTH_CHARS = 17;
 
-var UserListPopover = GObject.registerClass(
+const UserListPopover = GObject.registerClass(
 class UserListPopover extends Gtk.Popover {
     _init(params) {
         super._init(params);
@@ -41,20 +50,17 @@ class UserListPopover extends Gtk.Popover {
         this._box = new Gtk.Box({
             orientation: Gtk.Orientation.VERTICAL,
             spacing: 6,
+            margin_start: 6,
+            margin_end: 6,
+            margin_top: 6,
+            margin_bottom: 6,
         });
         this.add(this._box);
 
         this._revealer = new Gtk.Revealer();
         this._box.add(this._revealer);
 
-        this._userListBin = new Gtk.Frame({
-            shadow_type: Gtk.ShadowType.NONE,
-        });
-        this._box.add(this._userListBin);
-
-        this._entry = new Gtk.SearchEntry({
-            primary_icon_name: 'avatar-default-symbolic',
-        });
+        this._entry = new Gtk.SearchEntry();
         this._entry.connect('search-changed', this._updateFilter.bind(this));
         this._revealer.add(this._entry);
 
@@ -91,7 +97,7 @@ class UserListPopover extends Gtk.Popover {
             return;
 
         this._userList = new UserList(room);
-        this._userListBin.add(this._userList);
+        this._box.add(this._userList);
 
         this._userList.vadjustment.connect('changed',
             this._updateEntryVisibility.bind(this));
@@ -115,7 +121,7 @@ class UserListPopover extends Gtk.Popover {
     }
 });
 
-var UserDetails = GObject.registerClass({
+const UserDetails = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/user-details.ui',
     InternalChildren: [
         'spinnerBox',
@@ -316,7 +322,7 @@ var UserDetails = GObject.registerClass({
     }
 });
 
-var UserPopover = GObject.registerClass({
+const UserPopover = GObject.registerClass({
     Template: 'resource:///org/gnome/Polari/ui/user-popover.ui',
     InternalChildren: [
         'nickLabel',
@@ -469,8 +475,8 @@ class UserListRow extends Gtk.ListBoxRow {
             margin_bottom: 4,
             spacing: 4,
         });
-        this._arrow = new Gtk.Arrow({
-            arrow_type: Gtk.ArrowType.RIGHT,
+        this._arrow = new Gtk.Image({
+            icon_name: 'pan-end-symbolic',
             no_show_all: true,
         });
         this._label = new Gtk.Label({
@@ -539,16 +545,16 @@ class UserListRow extends Gtk.ListBoxRow {
     _onExpandedChanged() {
         if (this._revealer.reveal_child) {
             this.get_style_context().add_class('expanded');
-            this._arrow.arrow_type = Gtk.ArrowType.DOWN;
+            this._arrow.icon_name = 'pan-down-symbolic';
         } else {
             this.get_style_context().remove_class('expanded');
-            this._arrow.arrow_type = Gtk.ArrowType.RIGHT;
+            this._arrow.icon_name = 'pan-end-symbolic';
             this._updateArrowVisibility();
         }
     }
 });
 
-var UserList = GObject.registerClass(
+const UserList = GObject.registerClass(
 class UserList extends Gtk.ScrolledWindow {
     _init(room) {
         super._init({
@@ -565,7 +571,10 @@ class UserList extends Gtk.ScrolledWindow {
             halign: Gtk.Align.CENTER,
             valign: Gtk.Align.CENTER,
             orientation: Gtk.Orientation.VERTICAL,
-            margin: 32,
+            margin_top: 32,
+            margin_bottom: 32,
+            margin_start: 32,
+            margin_end: 32,
             spacing: 6,
             visible: true,
         });
